@@ -1,6 +1,6 @@
 use 5.38.0;
 use experimental 'class';
-
+our $VERSION = 0.02;
 class Game::Snake::Cell {
 	use Raylib::FFI;
 	use Raylib::Color;
@@ -17,3 +17,4 @@ class Game::Snake::Cell {
 		DrawRectangleLines($x, $y, $width, $height, Raylib::Color::WHITE);
 	}
 }
+1;
